Page 107 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 107

Home

    Following the pattern of "promising the opposite of
    what you intend to do," this candidate was sold to the
    American people as "a man of the little people" who
    would stand up to Wall Street. And, so it was that in
    1932, Franklin D. Roosevelt was elected president of the

    movement to socialize the United States began. This
    revolutionary plan was known as the "New Deal." The

    main agency created to carry out the revolution was the
    National Recovery Act (NRA). It was headed by
    representatives from Wall Street and big business.
    These socialists set out to regulate prices, wages, and
    working conditions throughout America. Controls were
    carried to such an extreme that a New Jersey tailor was

    fined and jailed for pressing a suit for five cents lower
    than the government allowed. Every move upon the part
    of the socialist planners served to prolong the depression,
    with unemployment being greater at the end of
    Roosevelt's first term in office than at the beginning.

    One event that slowed, but never stopped, America's
    descent into socialism was the Supreme Court's labeling
    of the fascist (merging of state and business) measures of
    the National Recovery Act as unconstitutional.

    Although slowed down in their plans to socialize the
    United States, the planners continued to work toward
    conditions that would lead to world government. While
    secretly preparing for war, Roosevelt, like Wilson,
    campaigned for reelection on a pledge that "Your boys

    with

    of

    102

    The Secret Side of History

    United States.

    As soon as Roosevelt was installed in office, the

    at the end